@@ -105,7 +105,8 @@ def col_from_invalue(invalue):
         
         #at this point some adjustments have to be made
         #the full_length value includes a position for sign and a decimal, if needed
-        result['length'] = int(groups['full_length'])# - 1  #unpad from sign #commented out because it is shorting the length
+        result['length'] = int(groups['full_length']) + 2
+        
         if groups['scale'] == '':
             result['scale'] = 0
         else:
@@ -115,6 +116,7 @@ def col_from_invalue(invalue):
             result['type'] = 'numeric'
         else:
             result['type'] = 'int'
+    
     elif key_capture is not None:
         result['length'] = int(key_capture.groupdict()['length'])
         result['type'] = 'int'#TODO: add support for bigint for key and any other lengthy ints
@@ -241,7 +243,11 @@ def long_table_sql(table_name, category, schema=None, ine=True, constraints=['DE
             dict(field='RATE', length=9, data_type='numeric', scale=2),
             dict(field='CHARGE', length=12, data_type='numeric', scale=2),
             dict(field='CHARGE_GROUP', length=5, data_type='numeric'),
+            dict(field='CPTHCPCS', length=5, data_type='char'),
+            dict(field='CPTMOD1', length=2, data_type='char'),
+            dict(field='CPTMOD2', length=2, data_type='char'),
         ]
+    
     elif category == 'DX':
         fields += [
             dict(field='DX', length=10, data_type='char'),
@@ -251,6 +257,7 @@ def long_table_sql(table_name, category, schema=None, ine=True, constraints=['DE
             dict(field='DXatAdmit', length=1, data_type='char'),
             dict(field='TMDX', length=1, data_type='char'),
         ]
+    
     elif category == 'PR':
         fields += [
             dict(field='PR', length=10, data_type='char'),
@@ -263,6 +270,7 @@ def long_table_sql(table_name, category, schema=None, ine=True, constraints=['DE
             dict(field='PCLASS', length=1, data_type='char'),
             dict(field='PRMCCS', length=8, data_type='char'),
         ]
+    
     else:
         raise Exception("At present only long charges (CHGS), diagnosis (DX), and procedure (PR) category tables are supported. (Got %s)" % category)
 
@@ -547,7 +555,7 @@ def pg_castcoltype(archtype, length, scale=None, all_char_as_varchar=True):
 
 def pg_wtl_shovel(cnxn, meta_df, category, tbl_source,
         tbl_destination, extra_fields=['state', 'year', 'key'],
-        preserve_source=False):
+        preserve_source=True):
     """Shovels wide things into long things
     
     category is 'CHGS' only, for now
@@ -664,7 +672,7 @@ def pg_wtl_shovel(cnxn, meta_df, category, tbl_source,
 
 
 def pg_shovel(cnxn, tbl_source, tbl_destination, fields_in, fields_out=False,
-              where_not_null=None, preserve_source=False, scalars=None):
+              where_not_null=None, preserve_source=True, scalars=None):
     """Attempts to move everything in tbl_source to tbl_destination using cnxn.
     
     The SQL used here is supported for sure in PostgreSQL but untested in other engines.
