@@ -21,14 +21,14 @@ BUNDLED_UFLAGDEF = os.path.join(dir_path, 'data', 'uflags', 'uflag_definitions.c
 
 # definitions for replacing missing values down the line
 MISSING_PATTERNS = {
-        'missing':        '((?:-9*\.?9*)[^-\.]| |\.)',
-        'invalid':        '((?:-8*\.?8*)[^-\.]|A)',
-        'unavailable':    '((?:-7*\.?7*)[^-\.])',
-        'inconsistent':   '((?:-6*\.?6*)[^-\.])',
-        'notapplicable':  '((?:-5*\.?5*)[^-\.])',
-        'tx_cell_too_sm': '(-?999+8)',
-        'tx_invalid':     '(\*)',
-        'tx_missing':     '(\.|`)',
+        'missing':        '-9*\.?9*[^-\.]| |\.',
+        'invalid':        '-8*\.?8*[^-\.]|A',
+        'unavailable':    '-7*\.?7*[^-\.]',
+        'inconsistent':   '-6*\.?6*[^-\.]',
+        'notapplicable':  '-5*\.?5*[^-\.]',
+        'tx_cell_too_sm': '-?999+8',
+        'tx_invalid':     '\*',
+        'tx_missing':     '\.|`',
         }
 
 # pre-compile for later use, or for accessing this via dot notation
@@ -113,7 +113,7 @@ def read(target, meta_df=None, state=None, year=None, variety=None,
 
 
 def replace_sentinels(df, extra_dict=None):
-    """Replaces HCUP SID sentinel patterns and values for bad data
+    """Replaces sentinel patterns and values for bad data
     
     HCUP definitions from http://www.hcup-us.ahrq.gov/db/coding.pdf
     TX PUDF definitions from individual year manuals http://www.dshs.state.tx.us/thcic/hospitals/Inpatientpudf.shtm
